Installation on Android — Kivy v1.0.1-dev documentation

# Installation on Android

Note

The android version is not fully supported yet. Check Android platform for more information about the current status.

You remind you that Kivy is a framework. Installing Kivy itself on your phone will do absolutly nothing. Kivy is not an application.

BUT, despite this agreement, we are releasing a “launcher”, that permit you to push your kivy application onto your phone, and execute them through a simple interface. We’ll provide instruction for packaging your kivy application in the future.

To install Kivy launcher, you can:

1. Go on the Kivy Launcher on the Android market
2. Click on Install
3. Select your phone.. and you’re done !

Now, you can push your Kivy’s applications in the kivy directory on the sdcard. Check the Android platform for learning specials tricks for android platform.

## Installation of examples

Warning

Theses examples are not final, just tests for Kivy environment.

1. Download the KivyTest for Android

2. Unzip the content into your sdcard of your phone, in the kivy directory:

       /sdcard/kivy

3. Run the launcher and select Kivytest